@@ -1,7 +1,7 @@
 /*
-    Qalculate    
+    Qalculate (library)
 
-    Copyright (C) 2004-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2004-2006, 2016  Hanna Knutsson (hanna_k@fmgirl.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <glib.h>
 
 #define XML_GET_STRING_FROM_PROP(node, name, str)	value = xmlGetProp(node, (xmlChar*) name); if(value) {str = (char*) value; remove_blank_ends(str); xmlFree(value);} else str = ""; 
 #define XML_GET_STRING_FROM_TEXT(node, str)		value = xmlNodeListGetString(doc, node->xmlChildrenNode, 1); if(value) {str = (char*) value; remove_blank_ends(str); xmlFree(value);} else str = "";
@@ -421,33 +422,69 @@ const string &DataSet::defaultDataFile() const {
 }
 	
 bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
-	string filename;
 	if(file_name) {
-		filename = file_name;
 	} else if(sfile.empty()) {
 		return false;
-	} else if(sfile.find("/") != string::npos) {
-		filename = sfile;
-		bool b = loadObjects(filename.c_str(), false);
-		size_t i = sfile.find_last_of("/");
+	} else if(sfile.find(G_DIR_SEPARATOR_S) != string::npos) {
+		bool b = loadObjects(file_name, false);
+		size_t i = sfile.find_last_of(G_DIR_SEPARATOR_S);
 		if(i != sfile.length() - 1) {
-			filename = getLocalDir();
-			filename += "definitions/";
-			filename += "datasets/";
-			filename += sfile.substr(i + 1, sfile.length() - (i + 1));
-			loadObjects(filename.c_str(), true);
+			gchar *filepath = g_build_filename(getLocalDataDir().c_str(), "definitions", "datasets", sfile.substr(i + 1, sfile.length() - (i + 1)).c_str(), NULL);
+			if(loadObjects(filepath, true)) {
+				b = true;
+			} else {
+				gchar *filepath_old = g_build_filename(getOldLocalDir().c_str(), "definitions", "datasets", sfile.substr(i + 1, sfile.length() - (i + 1)).c_str(), NULL);
+				if(loadObjects(filepath_old, true)) {
+					b = true;
+					mkdir(getLocalDataDir().c_str(), S_IRWXU);
+					gchar *dir = g_build_filename(getLocalDataDir().c_str(), "definitions", NULL);
+					mkdir(dir, S_IRWXU);
+					g_free(dir);
+					dir = g_build_filename(getLocalDataDir().c_str(), "definitions", "datasets", NULL);
+					mkdir(dir, S_IRWXU);
+					g_free(dir);
+					move_file(filepath_old, filepath);
+					dir = g_build_filename(getOldLocalDir().c_str(), "definitions", "datasets", NULL);
+					rmdir(dir);
+					g_free(dir);
+					dir = g_build_filename(getOldLocalDir().c_str(), "definitions", NULL);
+					rmdir(dir);
+					g_free(dir);
+				}
+				g_free(filepath_old);
+			}
+			g_free(filepath);
 		}
 		return b;
 	} else {
-		filename = PACKAGE_DATA_DIR;
-		filename += "/qalculate/";
-		filename += sfile;
-		bool b = loadObjects(filename.c_str(), false);
-		filename = getLocalDir();
-		filename += "definitions/";
-		filename += "datasets/";
-		filename += sfile;
-		loadObjects(filename.c_str(), true);
+		gchar *filepath = g_build_filename(PACKAGE_DATA_DIR, "qalculate", sfile.c_str(), NULL);
+		bool b = loadObjects(filepath, false);
+		g_free(filepath);
+		filepath = g_build_filename(getLocalDataDir().c_str(), "definitions", "datasets", sfile.c_str(), NULL);
+		if(loadObjects(filepath, true)) {
+			b = true;
+		} else {
+			gchar *filepath_old = g_build_filename(getOldLocalDir().c_str(), "definitions", "datasets", sfile.c_str(), NULL);
+			if(loadObjects(filepath_old, true)) {
+				b = true;
+				mkdir(getLocalDataDir().c_str(), S_IRWXU);
+				gchar *dir = g_build_filename(getLocalDataDir().c_str(), "definitions", NULL);
+				mkdir(dir, S_IRWXU);
+				g_free(dir);
+				dir = g_build_filename(getLocalDataDir().c_str(), "definitions", "datasets", NULL);
+				mkdir(dir, S_IRWXU);
+				g_free(dir);
+				move_file(filepath_old, filepath);
+				dir = g_build_filename(getOldLocalDir().c_str(), "definitions", "datasets", NULL);
+				rmdir(dir);
+				g_free(dir);
+				dir = g_build_filename(getOldLocalDir().c_str(), "definitions", NULL);
+				rmdir(dir);
+				g_free(dir);
+			}
+			g_free(filepath_old);
+		}
+		g_free(filepath);
 		return b;
 	}
 	xmlDocPtr doc;
@@ -470,10 +507,10 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 	}
 	while(localebase.length() < 2) localebase += " ";
 
-	doc = xmlParseFile(filename.c_str());
+	doc = xmlParseFile(file_name);
 	if(doc == NULL) {
 		if(!is_user_defs && !isLocal()) {
-			CALCULATOR->error(true, _("Unable to load data objects in %s."), filename.c_str(), NULL);
+			CALCULATOR->error(true, _("Unable to load data objects in %s."), file_name, NULL);
 		}
 		return false;
 	}
@@ -481,7 +518,7 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 	if(cur == NULL) {
 		xmlFreeDoc(doc);
 		if(!is_user_defs && !isLocal()) {
-			CALCULATOR->error(true, _("Unable to load data objects in %s."), filename.c_str(), NULL);
+			CALCULATOR->error(true, _("Unable to load data objects in %s."), file_name, NULL);
 		}
 		return false;
 	}
@@ -495,11 +532,11 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 		cur = cur->next;
 	}
 	if(cur == NULL) {
-		CALCULATOR->error(true, _("File not identified as Qalculate! definitions file: %s."), filename.c_str(), NULL);
+		CALCULATOR->error(true, _("File not identified as Qalculate! definitions file: %s."), file_name, NULL);
 		xmlFreeDoc(doc);
 		return false;
 	}
-	int version_numbers[] = {0, 0, 0};
+	/*int version_numbers[] = {0, 0, 0};
 	for(size_t i = 0; i < 3; i++) {
 		size_t dot_i = version.find(".");
 		if(dot_i == string::npos) {
@@ -508,7 +545,7 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 		}
 		version_numbers[i] = s2i(version.substr(0, dot_i));
 		version = version.substr(dot_i + 1, version.length() - (dot_i + 1));
-	}
+	}*/
 	DataObject *o = NULL;
 	cur = cur->xmlChildrenNode;
 	string str, str2;
@@ -697,13 +734,16 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 int DataSet::saveObjects(const char *file_name, bool save_global) {
 	string str, filename;
 	if(!save_global && !file_name) {
-		filename = getLocalDir();
+		mkdir(getLocalDataDir().c_str(), S_IRWXU);
+		gchar *gstr = g_build_filename(getLocalDataDir().c_str(), "definitions", NULL);		
+		mkdir(gstr, S_IRWXU);
+		gchar *gstr2 = g_build_filename(gstr, "datasets", NULL);
 		mkdir(filename.c_str(), S_IRWXU);
-		filename += "definitions/";
-		mkdir(filename.c_str(), S_IRWXU);
-		filename += "datasets/";
-		mkdir(filename.c_str(), S_IRWXU);
-		filename += sfile;
+		gchar *gstr3 = g_build_filename(gstr, sfile.c_str(), NULL);
+		filename = gstr3;
+		g_free(gstr);
+		g_free(gstr2);
+		g_free(gstr3);
 	} else {
 		filename = file_name;
 	}
