@@ -1,7 +1,7 @@
 /*
-    Qalculate    
+    Qalculate (library)
 
-    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna_k@fmgirl.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -397,7 +397,8 @@ bool ExpressionItem::isApproximate() const {
 void ExpressionItem::setApproximate(bool is_approx) {
 	if(is_approx != b_approx) {
 		b_approx = is_approx;
-		b_changed = true;	
+		if(!b_approx) i_precision = -1;
+		b_changed = true;
 	}
 }
 int ExpressionItem::precision() const {
