@@ -1,7 +1,7 @@
 /*
-    Qalculate    
+    Qalculate (library)
 
-    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna_k@fmgirl.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -58,6 +58,8 @@ typedef enum {
 	SUBTYPE_DATA_SET
 } FunctionSubtype;
 
+class MathFunction_p;
+
 /// Abstract base class for mathematical functions.
 /**
 * A mathemical function, subclassed from MathFunction, should at least reimplement
@@ -68,10 +70,10 @@ class MathFunction : public ExpressionItem {
 
   protected:
 
+	MathFunction_p *priv;
 	int argc;
 	int max_argc;
 	vector<string> default_values;
-	Sgi::hash_map<size_t, Argument*> argdefs;
 	size_t last_argdef_index;		
 	bool testArguments(MathStructure &vargs);
 	virtual MathStructure createFunctionMathStructureFromVArgs(const MathStructure &vargs);
