@@ -1,7 +1,7 @@
 /*
-    Qalculate    
+    Qalculate (library)
 
-    Copyright (C) 2004-2007  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna_k@fmgirl.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -164,9 +164,7 @@ class MathStructure {
 		
 		bool isolate_x_sub(const EvaluationOptions &eo, EvaluationOptions &eo2, const MathStructure &x_var, MathStructure *morig = NULL);
 		void init();
-        
-        MathStructure& CHILD(size_t v_index) const;
-        
+	
 	public:
 
 		/** @name Constructors */
@@ -297,6 +295,11 @@ class MathStructure {
 		* @param preserve_precision Preserve the current precision.
 		*/
 		void setUndefined(bool preserve_precision = false);
+		/** Mark that calculation was aborted.
+		*
+		* @param preserve_precision Preserve the current precision.
+		*/
+		void setAborted(bool preserve_precision = false);
 		/** Reset the value (to zero) and parameters of the structure.
 		*
 		* @param preserve_precision Preserve the current precision.
@@ -350,7 +353,9 @@ class MathStructure {
 		/** @name Functions for units */
 		//@{
 		Unit *unit() const;
+		Unit *unit_exp_unit() const;
 		Prefix *prefix() const;
+		Prefix *unit_exp_prefix() const;
 		void setPrefix(Prefix *p);
 		bool isPlural() const;
 		void setPlural(bool is_plural);
@@ -407,8 +412,8 @@ class MathStructure {
 		void delChild(size_t index);
 		void insertChild(const MathStructure &o, size_t index);
 		void insertChild_nocopy(MathStructure *o, size_t index);
-		void setChild(const MathStructure &o, size_t index = 1);
-		void setChild_nocopy(MathStructure *o, size_t index = 1);
+		void setChild(const MathStructure &o, size_t index = 1, bool merge_precision = false);
+		void setChild_nocopy(MathStructure *o, size_t index = 1, bool merge_precision = false);
 		const MathStructure *getChild(size_t index) const;
 		MathStructure *getChild(size_t index);
 		size_t countChildren() const;
@@ -438,6 +443,7 @@ class MathStructure {
 		bool isMultiplication() const;
 		bool isPower() const;
 		bool isSymbolic() const;
+		bool isAborted() const;
 		bool isEmptySymbol() const;
 		bool isVector() const;
 		bool isMatrix() const;
@@ -488,9 +494,9 @@ class MathStructure {
 	
 		/** @name Functions for precision */
 		//@{
-		void setApproximate(bool is_approx = true);	
+		void setApproximate(bool is_approx = true, bool recuresive = false);
 		bool isApproximate() const;		
-		void setPrecision(int prec);
+		void setPrecision(int prec, bool recursive = false);
 		int precision() const;
 		void mergePrecision(const MathStructure &o);
 		//@}
@@ -756,8 +762,9 @@ class MathStructure {
 		bool syncUnits(bool sync_complex_relations = false, bool *found_complex_relations = NULL, bool calculate_new_functions = false, const EvaluationOptions &feo = default_evaluation_options);
 		bool testDissolveCompositeUnit(Unit *u);
 		bool testCompositeUnit(Unit *u);	
-		bool dissolveAllCompositeUnits();			
-		bool convert(Unit *u, bool convert_complex_relations = false, bool *found_complex_relations = NULL, bool calculate_new_functions = false, const EvaluationOptions &feo = default_evaluation_options);
+		bool dissolveAllCompositeUnits();
+		bool setPrefixForUnit(Unit *u, Prefix *new_prefix);
+		bool convert(Unit *u, bool convert_complex_relations = false, bool *found_complex_relations = NULL, bool calculate_new_functions = false, const EvaluationOptions &feo = default_evaluation_options, Prefix *new_prefix = NULL);
 		bool convert(const MathStructure unit_mstruct, bool convert_complex_relations = false, bool *found_complex_relations = NULL, bool calculate_new_functions = false, const EvaluationOptions &feo = default_evaluation_options);
 		//@}
 		
@@ -767,6 +774,7 @@ class MathStructure {
 		int containsRepresentativeOf(const MathStructure &mstruct, bool check_variables = false, bool check_functions = false) const;
 		int containsType(StructureType mtype, bool structural_only = true, bool check_variables = false, bool check_functions = false) const;
 		int containsRepresentativeOfType(StructureType mtype, bool check_variables = false, bool check_functions = false) const;
+		int containsFunction(MathFunction *f, bool structural_only = true, bool check_variables = false, bool check_functions = false) const;
 		bool containsOpaqueContents() const;
 		bool containsAdditionPower() const;
 		bool containsUnknowns() const;
