@@ -1,7 +1,7 @@
 /*
-    Qalculate    
+    Qalculate (library)
 
-    Copyright (C) 2003-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna_k@fmgirl.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@ class Unit : public ExpressionItem {
 
 	string ssystem;
 	bool b_si;
+	bool b_use_with_prefixes;
 
   public:
 
@@ -61,7 +62,7 @@ class Unit : public ExpressionItem {
 	* Sets system to "SI".
 	*/
 	void setAsSIUnit();
-	/** Sets which system/standard ("SI", "SGC", etc.) the unit is part of.
+	/** Sets which system/standard ("SI", "CGS", etc.) the unit is part of.
 	* Setting system to "SI" (case-insensitive), is equivalent to setAsSIUnit().
 	*/
 	void setSystem(string s_system);
@@ -69,7 +70,15 @@ class Unit : public ExpressionItem {
 	*
 	* @returns System string.
 	*/
-	const string &system() const;
+	const string &system() const;	
+	/** Returns wether prefixes should be used with this unit or not.
+	*
+	* @returns true if the prefixes is appropriate for this unit.
+	*/
+	bool useWithPrefixesByDefault() const;
+	/** Sets wether prefixes are approriate with this unit or not.
+	*/
+	void setUseWithPrefixesByDefault(bool use_with_prefixes);
 	/** Returns if the unit is a currency (Euro is base unit).
 	*
 	* @returns true if the unit is a currency.
@@ -290,8 +299,8 @@ class CompositeUnit : public Unit {
 		virtual bool containsRelativeTo(Unit *u) const;
 		/** Creates a MathStructure with the sub/base units of the unit.
 		*/
-		virtual MathStructure generateMathStructure(bool make_division = false) const;
-		virtual void setBaseExpression(string base_expression_);		
+		virtual MathStructure generateMathStructure(bool make_division = false, bool set_null_prefixes = false) const;
+		virtual void setBaseExpression(string base_expression_);
 		/** Removes all sub/base units. */
 		virtual void clear();
 };
